==> networkmonitor-1.0.15.3-sources.jar: com/transsin/networkmonitor/MonitorFactory.java <==
package com.transsin.networkmonitor;

import static com.transsin.networkmonitor.Consts.NORMAL;
import static com.transsin.networkmonitor.Utils.GLOBAL_TAG;

import okhttp3.Call;
import okhttp3.EventListener;

/**
 * @Author:huangxiushuo
 * @Date: 2023-05-25 19:51
 * @Description:
 */
public class MonitorFactory implements EventListener.Factory {

    private EventListener.Factory factory;

    private int usage = NORMAL;

    private boolean shouldUploadData = false;

    private String channel = "All";

    public MonitorFactory() {
    }

    public MonitorFactory(EventListener.Factory factory) {
        this.factory = factory;
    }

    public MonitorFactory(EventListener.Factory factory, int usage, boolean shouldUploadData) {
        this.factory = factory;
        this.usage = usage;
        this.shouldUploadData = shouldUploadData;
    }

    public MonitorFactory(EventListener.Factory factory, int usage, boolean shouldUploadData, String channel) {
        this.factory = factory;
        this.usage = usage;
        this.shouldUploadData = shouldUploadData;
        this.channel = channel;
    }

    @Override
    public EventListener create(Call call) {
        EventListener eventListener = null;
        if (factory != null) {
            eventListener = factory.create(call);
        }
        String host = call.request().url().host();
        if (HostMatcher.noHosts() || HostMatcher.match(host)) {
            Utils.LOG.d(GLOBAL_TAG, "==== MonitorFactory host : ${host} matches ====");
            return new MonitorEventListener(eventListener, usage, shouldUploadData, channel);
        } else {
            Utils.LOG.d(GLOBAL_TAG, "==== MonitorFactory host : ${host} does not matche ====");
            return eventListener == null ? EventListener.NONE : eventListener;
        }
    }
}

==> networkmonitor-1.0.15.6-sources.jar: com/transsin/networkmonitor/MonitorFactory.java <==
package com.transsin.networkmonitor;

import static com.transsin.networkmonitor.Consts.NORMAL;
import static com.transsin.networkmonitor.Utils.GLOBAL_TAG;

import okhttp3.Call;
import okhttp3.EventListener;

/**
 * @Author:huangxiushuo
 * @Date: 2023-05-25 19:51
 * @Description:
 */
public class MonitorFactory implements EventListener.Factory {

    private EventListener.Factory factory;

    private int usage = NORMAL;

    private boolean notReportData = false;

    private String channel = "All";

    public MonitorFactory() {
    }

    public MonitorFactory(EventListener.Factory factory) {
        this.factory = factory;
    }

    public MonitorFactory(EventListener.Factory factory, int usage, boolean notReportData) {
        this.factory = factory;
        this.usage = usage;
        this.notReportData = notReportData;
    }

    public MonitorFactory(EventListener.Factory factory, int usage, boolean notReportData, String channel) {
        this.factory = factory;
        this.usage = usage;
        this.notReportData = notReportData;
        this.channel = channel;
    }

    @Override
    public EventListener create(Call call) {
        EventListener eventListener = null;
        if (factory != null) {
            eventListener = factory.create(call);
        }
        String host = call.request().url().host();
        if (HostMatcher.noHosts() || HostMatcher.match(host)) {
            Utils.LOG.d(GLOBAL_TAG, "==== MonitorFactory host : ${host} matches ====");
            return new MonitorEventListener(eventListener, usage, notReportData, channel);
        } else {
            Utils.LOG.d(GLOBAL_TAG, "==== MonitorFactory host : ${host} does not matche ====");
            return eventListener == null ? EventListener.NONE : eventListener;
        }
    }
}
